==> haskell-configurator-ng-0.0.0.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-ng.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-ng
version: 0.0.0.1
id: configurator-ng-0.0.0.1-6xJC3hHlbHCIcO13ffwcnf
key: configurator-ng-0.0.0.1-6xJC3hHlbHCIcO13ffwcnf
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability: experimental
homepage: http://github.com/lpsmith/configurator-ng
synopsis: The next generation of configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    * An expressive applicative/monadic high-level parsing interface
    to gracefully scale to more complicated configuration needs,  with
    powerful diagnostic messaging mechanism.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan, Leon P Smith
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Config
    Data.Configurator.Config.Internal Data.Configurator.FromValue
    Data.Configurator.FromValue.Internal Data.Configurator.Parser
    Data.Configurator.Parser.Internal Data.Configurator.Types
hidden-modules: Data.Configurator.Config.Implementation
                Data.Configurator.Parser.Implementation
                Data.Configurator.FromValue.Implementation Data.Configurator.Syntax
                Data.Configurator.Types.Internal
abi: d3bdf03253947b1051cd51376526fd44
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/configurator-ng-0.0.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/configurator-ng-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/configurator-ng-0.0.0.1
hs-libraries: HSconfigurator-ng-0.0.0.1-6xJC3hHlbHCIcO13ffwcnf
depends:
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    bytestring-0.10.8.1 critbit-0.2.0.0-8eIktk1DYx6JTD7vUxgZgF
    data-ordlist-0.4.7.0-D6ij7F9rr5a9kcQtGict4V directory-1.3.0.0
    dlist-0.8.0.3-BHFBNaw8k6n9WiaUNzoXpk
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-configurator-ng/html/configurator-ng.haddock
haddock-html: /usr/share/doc/haskell-configurator-ng/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-ng-0.0.0.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-ng.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-ng
version: 0.0.0.1
id: configurator-ng-0.0.0.1-6wUkWEt3eLsLtu1vhPRZ4t
key: configurator-ng-0.0.0.1-6wUkWEt3eLsLtu1vhPRZ4t
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability: experimental
homepage: http://github.com/lpsmith/configurator-ng
synopsis: The next generation of configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    * An expressive applicative/monadic high-level parsing interface
    to gracefully scale to more complicated configuration needs,  with
    powerful diagnostic messaging mechanism.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan, Leon P Smith
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Config
    Data.Configurator.Config.Internal Data.Configurator.FromValue
    Data.Configurator.FromValue.Internal Data.Configurator.Parser
    Data.Configurator.Parser.Internal Data.Configurator.Types
hidden-modules: Data.Configurator.Config.Implementation
                Data.Configurator.Parser.Implementation
                Data.Configurator.FromValue.Implementation Data.Configurator.Syntax
                Data.Configurator.Types.Internal
abi: 914dc348e82f91a6c963073d520ccab0
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/configurator-ng-0.0.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/configurator-ng-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/configurator-ng-0.0.0.1
hs-libraries: HSconfigurator-ng-0.0.0.1-6wUkWEt3eLsLtu1vhPRZ4t
depends:
    attoparsec-0.13.2.0-JkqjYPxw7sG9Iq2J4E1Ndn base-4.9.1.0
    bytestring-0.10.8.1 critbit-0.2.0.0-8eIktk1DYx6JTD7vUxgZgF
    data-ordlist-0.4.7.0-D6ij7F9rr5a9kcQtGict4V directory-1.3.0.0
    dlist-0.8.0.3-BHFBNaw8k6n9WiaUNzoXpk
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-configurator-ng/html/configurator-ng.haddock
haddock-html: /usr/share/doc/haskell-configurator-ng/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
